@@ -55,20 +55,21 @@ def formatted_amount(amount):
     """ Format a price as a string, giving full coin descriptions. Returns 'no money' if amount is 0. """
     if amount == 0:
         return 'no money'
-    
+
     return Crossfire.CostStringFromValue(amount)
 
 def find_mailbox(object):
     while (object.Name != 'mailbox'):
         object = object.Above
         if not object:
-                return 0
+            return 0
     return object
+
 def FindCoin(object):
     while (object.Name.find('silver coin')==-1):
         object = object.Above
         if not object:
-                return 0
+            return 0
     return object
 
 class GuildDues:
@@ -94,8 +95,8 @@ class GuildDues:
         '''Handles buying a guild extension'''
 
         if (not CheckClearance([self.guildname, "GuildMaster"], activator)):
-                whoami.Say("Only guild masters and GMs can buy extensions or new desks for the guild.")
-                return
+            whoami.Say("Only guild masters and GMs can buy extensions or new desks for the guild.")
+            return
 
         # This lists all items that can be bought, extensions or new desks
         Items = {
@@ -168,14 +169,14 @@ class GuildDues:
             return
 
         if item in Cards:
-                card = activator.CreateObject('diploma')
-                card.Name = item
-                card.Message = 'This enables you to buy a new ' + item + ' for your guild.'
-                card.Value = 0
-                bank.withdraw(self.accountname, Price)
-                whoami.Say("Here is your card\nThe guild now has %s on account." %(formatted_amount(bank.getbalance(self.accountname))))
+            card = activator.CreateObject('diploma')
+            card.Name = item
+            card.Message = 'This enables you to buy a new ' + item + ' for your guild.'
+            card.Value = 0
+            bank.withdraw(self.accountname, Price)
+            whoami.Say("Here is your card\nThe guild now has %s on account." %(formatted_amount(bank.getbalance(self.accountname))))
 
-                return
+            return
 
         Loc = Rooms.get(item)
         coin = Loc[0].ObjectAt(Loc[1], Loc[2])
@@ -208,13 +209,13 @@ class GuildDues:
         priceFactor = 50	# platinum to silver conversion
 
         if activator.PayAmount(priceMailScroll*priceFactor):
-                whoami.Say('Here is your mailscroll to %s'%text[1])
-                id = activator.CreateObject('scroll')
-                id.Name = 'mailscroll T: '+text[1]+' F: '+activator.Name
-                id.NamePl = 'mailscrolls T: '+text[1]+' F: '+activator.Name
-                id.Value = 0
+            whoami.Say('Here is your mailscroll to %s'%text[1])
+            id = activator.CreateObject('scroll')
+            id.Name = 'mailscroll T: '+text[1]+' F: '+activator.Name
+            id.NamePl = 'mailscrolls T: '+text[1]+' F: '+activator.Name
+            id.Value = 0
         else:
-                whoami.Say('You need %s platinum for a mailscroll'%priceMailScroll)
+            whoami.Say('You need %s platinum for a mailscroll'%priceMailScroll)
 
     def do_balance(self):
         '''Handle the display of the guild's balance.'''
@@ -224,31 +225,35 @@ class GuildDues:
 
     def do_pay(self, text):
         '''Handle player paying dues to the guild.'''
-        if len(text) < 2:
+        if len(text) < 3:
             whoami.Say("How much ya wanna pay %s?\nYou can specify amounts in "%(random.choice(buddylist)) +
             ', '.join(i.lower() for i in CoinTypes.keys()))
             return
 
         cost = text[1]
-        type = ' '.join(text[2:])
-        utype = type.upper()
-        if not utype in CoinTypes.keys():
-            whoami.Say("Sorry, I don't know what are %s"%type)
+        currency = ' '.join(text[2:])
+        ucurrency = currency.upper()
+        if not ucurrency in CoinTypes.keys():
+            whoami.Say("Sorry, I don't know what %s are" % currency)
             return
 
-        conversionfactor = CoinTypes.get(utype)
+        conversionfactor = CoinTypes.get(ucurrency)
         total = int(cost)*conversionfactor
-        if activator.PayAmount(total):
+        if total and activator.PayAmount(total):
             guild = CFGuilds.CFGuild(self.guildname)
             guild.pay_dues(activator.Name,total)
-            whoami.Say("%s, %s %s paid to the guild." %(random.choice(remarklist), cost, type))
+            whoami.Say("%s, %s %s paid to the guild." % (random.choice(remarklist), cost, currency))
             bank = CFBank.CFBank(bankdatabase)
             bank.deposit(self.accountname, total)
         else:
-            if cost > 1:
-                whoami.Say("%s, you don't have %s %ss." %(random.choice(exclaimlist), cost, type))
+            if total == 0:
+                whoami.Say("Uh? Ya wanna trick me, %s." % random.choice(buddylist))
+            elif int(cost) > 1:
+                plural=''
+                if ucurrency.endswith('NOTE'): plural = 's'
+                whoami.Say("%s, you don't have %s %s%s." % (random.choice(exclaimlist), cost, currency, plural))
             else:
-                whoami.Say("You don't have any %s, %s." %(type, random.choice(buddylist)))
+                whoami.Say("You don't have any %s, %s." % (currency, random.choice(buddylist)))
 
     def do_withdraw(self, text):
         if (not activator.DungeonMaster==1 and not CheckClearance([self.guildname,"Master"],activator)):
@@ -276,17 +281,17 @@ class GuildDues:
         Value = CoinTypes.get(Type.upper())
 
         if Amount*Value <= balance:
-                message = (str(Amount))
-                message +=" " + Type + " withdrawn.\nYour new present balance is "
+            message = (str(Amount))
+            message +=" " + Type + " withdrawn.\nYour new present balance is "
 
-                id = activator.CreateObject(ArchType.get(Type.upper()))
-                CFItemBroker.Item(id).add(Amount)
-                bank.withdraw(self.accountname, Amount*Value)
-                message += formatted_amount(bank.getbalance(self.accountname))+"."
-                whoami.Say(message)
+            id = activator.CreateObject(ArchType.get(Type.upper()))
+            CFItemBroker.Item(id).add(Amount)
+            bank.withdraw(self.accountname, Amount*Value)
+            message += formatted_amount(bank.getbalance(self.accountname))+"."
+            whoami.Say(message)
         else:
-                message="You only have " + formatted_amount(bank.getbalance(self.accountname))+" on your account."
-                whoami.Say(message)
+            message="You only have " + formatted_amount(bank.getbalance(self.accountname))+" on your account."
+            whoami.Say(message)
 
     def handle_jack(self):
         '''Handle Jack, the guild helper'''
